==> google_applovin_unity_ads-2.3.18.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinRewardedAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.MaxAd;
import com.applovin.mediation.MaxAdListener;
import com.applovin.mediation.MaxError;
import com.applovin.mediation.MaxReward;
import com.applovin.mediation.MaxRewardedAdListener;
import com.applovin.mediation.ads.MaxInterstitialAd;
import com.applovin.mediation.ads.MaxRewardedAd;
import com.applovin.sdk.AppLovinSdk;
import com.google.android.gms.ads.AdError;
import com.google.android.gms.ads.LoadAdError;
import com.google.android.gms.ads.rewarded.RewardItem;
import com.google.android.gms.ads.rewarded.RewardedAd;

import java.lang.ref.WeakReference;

/**
 * A wrapper for {@link RewardedAd}.
 */
class FlutterAppLovinRewardedAd extends FlutterAd.FlutterOverlayAd {
    private static final String TAG = "FlutterRewardedAd";

    @NonNull
    private final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final FlutterAdLoader flutterAdLoader;
    @NonNull
    private final AppLovinSdk appLovinSdk;
    @Nullable
    MaxRewardedAd rewardedAd;

    /**
     * Constructor for AdMob Ad Request.
     */
    public FlutterAppLovinRewardedAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull FlutterAdLoader flutterAdLoader,
            @NonNull AppLovinSdk appLovinSdk) {
        super(adId);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.flutterAdLoader = flutterAdLoader;
        this.appLovinSdk = appLovinSdk;
    }

    @Override
    void load() {
        rewardedAd = MaxRewardedAd.getInstance(adUnitId, appLovinSdk, manager.getActivity());
        final MaxRewardedAdListener callback = new DelegatingRewardedCallback(this);
        /*if (geoSdkFactory != null) {
            geoSdkFactory.setGeoRewardListener(rewardedAd, callback);
        } else {*/
            rewardedAd.setListener(callback);
        /*}*/
        rewardedAd.loadAd();
    }

    void onAdLoaded(@NonNull MaxAd rewardedAd) {
        manager.onAdLoaded(adId, null);
    }

    void onAdFailedToLoad(@NonNull LoadAdError loadAdError) {
        manager.onAdFailedToLoad(adId, new FlutterLoadAdError(loadAdError));
    }

    @Override
    public void show() {
        if (rewardedAd == null) {
            Log.e(TAG, "Error showing rewarded - the rewarded ad wasn't loaded yet.");
            return;
        }
        if (manager.getActivity() == null) {
            Log.e(TAG, "Tried to show rewarded ad before activity was bound to the plugin.");
            return;
        }
        /*if (geoSdkFactory != null) {
            if (geoSdkFactory.isGeoAdShow(rewardedAd)) {
                rewardedAd.showAd();
            } else {
                onAdFailedToLoad(new LoadAdError(8520, "ad is blocked", "", null, null));
            }
        } else {*/
            rewardedAd.showAd();
//        }
    }

    @Override
    public void setImmersiveMode(boolean immersiveModeEnabled) {
    }

    void onUserEarnedReward(@NonNull RewardItem rewardItem) {
        manager.onRewardedAdUserEarnedReward(
                adId, new FlutterRewardedAd.FlutterRewardItem(rewardItem.getAmount(), rewardItem.getType()));
    }

    @Override
    void dispose() {
        if(rewardedAd != null)
            rewardedAd.destroy();

        rewardedAd = null;
    }

    /**
     * This class delegates various rewarded ad callbacks to FlutterRewardedAd. Maintains a weak
     * reference to avoid memory leaks.
     */
    private static final class DelegatingRewardedCallback
            implements MaxRewardedAdListener {

        private final WeakReference<FlutterAppLovinRewardedAd> delegate;

        DelegatingRewardedCallback(FlutterAppLovinRewardedAd delegate) {
            this.delegate = new WeakReference<>(delegate);
        }

/*
        @Override
        public void onAdMetadataChanged() {
            if (delegate.get() != null) {
                delegate.get().onAdMetadataChanged();
            }
        }*/

        @Override
        public void onRewardedVideoStarted(MaxAd ad) {

        }

        @Override
        public void onRewardedVideoCompleted(MaxAd ad) {

        }

        @Override
        public void onUserRewarded(MaxAd ad, MaxReward reward) {
            if (delegate.get() != null) {
                delegate.get().onUserEarnedReward(new RewardItem() {
                    @Override
                    public int getAmount() {
                        return reward.getAmount();
                    }

                    @NonNull
                    @Override
                    public String getType() {
                        return "";
                    }
                });
            }
        }

        @Override
        public void onAdLoaded(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().onAdLoaded(ad);
            }
        }

        @Override
        public void onAdDisplayed(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdShowedFullScreenContent(delegate.get().adId);
            }
        }

        @Override
        public void onAdHidden(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdDismissedFullScreenContent(delegate.get().adId);
            }
        }

        @Override
        public void onAdClicked(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdClicked(delegate.get().adId);
            }
        }

        @Override
        public void onAdLoadFailed(String adUnitId, MaxError error) {
            if (delegate.get() != null) {
                delegate.get().onAdFailedToLoad(new LoadAdError(error.getCode(), error.getMessage(), String.valueOf(error.getMediatedNetworkErrorCode()), null, null));
            }
        }

        @Override
        public void onAdDisplayFailed(MaxAd ad, MaxError error) {
            if (delegate.get() != null) {
                delegate.get().manager.onFailedToShowFullScreenContent(delegate.get().adId, new AdError(error.getCode(), error.getMessage(), String.valueOf(error.getMediatedNetworkErrorCode())));
            }
        }
    }
}

==> google_applovin_unity_ads-2.3.20.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinRewardedAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.appharbr.sdk.engine.AdSdk;
import com.appharbr.sdk.engine.AdStateResult;
import com.appharbr.sdk.engine.AppHarbr;
import com.applovin.mediation.MaxAd;
import com.applovin.mediation.MaxAdListener;
import com.applovin.mediation.MaxError;
import com.applovin.mediation.MaxReward;
import com.applovin.mediation.MaxRewardedAdListener;
import com.applovin.mediation.ads.MaxInterstitialAd;
import com.applovin.mediation.ads.MaxRewardedAd;
import com.applovin.sdk.AppLovinSdk;
import com.google.android.gms.ads.AdError;
import com.google.android.gms.ads.LoadAdError;
import com.google.android.gms.ads.rewarded.RewardItem;
import com.google.android.gms.ads.rewarded.RewardedAd;

import java.lang.ref.WeakReference;

/**
 * A wrapper for {@link RewardedAd}.
 */
class FlutterAppLovinRewardedAd extends FlutterAd.FlutterOverlayAd {
    private static final String TAG = "FlutterRewardedAd";

    @NonNull
    private final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final Boolean isAppharbarSuccess;
    @NonNull
    private final FlutterAdLoader flutterAdLoader;
    @NonNull
    private final AppLovinSdk appLovinSdk;
    @Nullable
    MaxRewardedAd rewardedAd;

    /**
     * Constructor for AdMob Ad Request.
     */
    public FlutterAppLovinRewardedAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull FlutterAdLoader flutterAdLoader,
            @NonNull Boolean isAppharbarSuccess,
            @NonNull AppLovinSdk appLovinSdk) {
        super(adId);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.isAppharbarSuccess = isAppharbarSuccess;
        this.flutterAdLoader = flutterAdLoader;
        this.appLovinSdk = appLovinSdk;
    }

    @Override
    void load() {
        rewardedAd = MaxRewardedAd.getInstance(adUnitId, appLovinSdk, manager.getActivity());
        MaxRewardedAdListener callback = new DelegatingRewardedCallback(this);
        if (isAppharbarSuccess) {
            callback = AppHarbr.addRewardedAd(
                    AdSdk.MAX,
                    rewardedAd,
                    callback,
                    null,
                    (o, s, adFormat, adBlockReasons) -> {}
            );
        }
        rewardedAd.setListener(callback);
        rewardedAd.loadAd();
    }

    void onAdLoaded(@NonNull MaxAd rewardedAd) {
        manager.onAdLoaded(adId, null);
    }

    void onAdFailedToLoad(@NonNull LoadAdError loadAdError) {
        manager.onAdFailedToLoad(adId, new FlutterLoadAdError(loadAdError));
    }

    @Override
    public void show() {
        if (rewardedAd == null) {
            Log.e(TAG, "Error showing rewarded - the rewarded ad wasn't loaded yet.");
            return;
        }
        if (manager.getActivity() == null) {
            Log.e(TAG, "Tried to show rewarded ad before activity was bound to the plugin.");
            return;
        }

        if (isAppharbarSuccess) {
            AdStateResult result = AppHarbr.getRewardedState(rewardedAd);
            Log.e(TAG, "show: "+result );
            if (rewardedAd.isReady() && result != AdStateResult.BLOCKED) {
                rewardedAd.showAd();
            } else {
                onAdFailedToLoad(new LoadAdError(101, "AdBlocker Apply", "", null, null));
            }
        } else {
            if (rewardedAd.isReady()) {
                rewardedAd.showAd();
            } else {
                onAdFailedToLoad(new LoadAdError(101, "Ad is not ready", "", null, null));
            }
        }
    }

    @Override
    public void setImmersiveMode(boolean immersiveModeEnabled) {
    }

    void onUserEarnedReward(@NonNull RewardItem rewardItem) {
        manager.onRewardedAdUserEarnedReward(
                adId, new FlutterRewardedAd.FlutterRewardItem(rewardItem.getAmount(), rewardItem.getType()));
    }

    @Override
    void dispose() {
        if(rewardedAd != null)
            rewardedAd.destroy();

        rewardedAd = null;
    }

    /**
     * This class delegates various rewarded ad callbacks to FlutterRewardedAd. Maintains a weak
     * reference to avoid memory leaks.
     */
    private static final class DelegatingRewardedCallback
            implements MaxRewardedAdListener {

        private final WeakReference<FlutterAppLovinRewardedAd> delegate;

        DelegatingRewardedCallback(FlutterAppLovinRewardedAd delegate) {
            this.delegate = new WeakReference<>(delegate);
        }

/*
        @Override
        public void onAdMetadataChanged() {
            if (delegate.get() != null) {
                delegate.get().onAdMetadataChanged();
            }
        }*/

        @Override
        public void onRewardedVideoStarted(MaxAd ad) {

        }

        @Override
        public void onRewardedVideoCompleted(MaxAd ad) {

        }

        @Override
        public void onUserRewarded(MaxAd ad, MaxReward reward) {
            if (delegate.get() != null) {
                delegate.get().onUserEarnedReward(new RewardItem() {
                    @Override
                    public int getAmount() {
                        return reward.getAmount();
                    }

                    @NonNull
                    @Override
                    public String getType() {
                        return "";
                    }
                });
            }
        }

        @Override
        public void onAdLoaded(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().onAdLoaded(ad);
            }
        }

        @Override
        public void onAdDisplayed(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdShowedFullScreenContent(delegate.get().adId);
            }
        }

        @Override
        public void onAdHidden(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdDismissedFullScreenContent(delegate.get().adId);
            }
        }

        @Override
        public void onAdClicked(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdClicked(delegate.get().adId);
            }
        }

        @Override
        public void onAdLoadFailed(String adUnitId, MaxError error) {
            if (delegate.get() != null) {
                delegate.get().onAdFailedToLoad(new LoadAdError(error.getCode(), error.getMessage(), String.valueOf(error.getMediatedNetworkErrorCode()), null, null));
            }
        }

        @Override
        public void onAdDisplayFailed(MaxAd ad, MaxError error) {
            if (delegate.get() != null) {
                delegate.get().manager.onFailedToShowFullScreenContent(delegate.get().adId, new AdError(error.getCode(), error.getMessage(), String.valueOf(error.getMediatedNetworkErrorCode())));
            }
        }
    }
}
